@@ -1,4 +1,4 @@
-/* $Id: kildclient.h,v 1.147 2006/08/10 14:36:33 ekalin Exp $ */
+/* $Id: kildclient.h,v 1.149 2007/05/13 22:00:56 ekalin Exp $ */
 
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -396,9 +396,11 @@ struct world_s
 
   /* Buffers and state */
   TelnetState      telnet_state;             /* State of Telnet IAC FSM */
+  gint             telnet_state_ncrs;        /* Last # of \r seen in a row */
   guchar           inbuffer[MAX_BUFFER];     /* Input buffer from network */
   guchar           dbuffer[MAX_BUFFER];      /* Buffer for decompressed data */
-  guchar           pbuffer[MAX_BUFFER];      /* Buffer to process */
+  guchar          *pbuffer;                  /* Buffer to process */
+  guint            pbuf_alloc_size;          /* Current size of pbuffer */
   int              pbuf_size;                /* Buffer size */
   /* For MCCP handling */
   z_stream        *zstream;                  /* Used for decompression */
@@ -735,6 +737,7 @@ gboolean   open_new_world(WorldGUI    *gui,
                           gboolean    *offline_selected);
 gboolean   update_times_cb(gpointer data);
 gboolean   confirm_quit(void);
+void       worldgui_destroy_tooltip_window(WorldGUI *gui);
 G_MODULE_EXPORT void     menu_findnext_activate_cb(GtkWidget *widget,
                                                    gpointer   data);
 
