@@ -1,4 +1,4 @@
-/* $Id: net.c,v 1.90 2006/04/25 13:13:24 ekalin Exp $ */
+/* $Id: net.c,v 1.92 2007/05/13 22:00:56 ekalin Exp $ */
 
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -115,6 +115,13 @@ disconnect_world(gpointer data)
 
   currentWorld = NULL;
 
+  /* Remove the tooltip */
+  worldgui_destroy_tooltip_window(world->gui);
+  if (world->gui->tooltip_timeout_id) {
+    g_source_remove(world->gui->tooltip_timeout_id);
+    world->gui->tooltip_timeout_id = 0;
+  }
+
   /* Here we decide what to do */
   action = disconnected_msgbox(msg, TRUE);
   g_free(msg);
@@ -512,6 +519,7 @@ process_telnet_iac(World *world, int pos, int end)
         break;
 
       case '\r':
+        world->telnet_state_ncrs = 1;
         world->telnet_state = TELNETFSM_DATA_CR;
         break;
 
@@ -535,12 +543,24 @@ process_telnet_iac(World *world, int pos, int end)
       if (world->dbuffer[pos] == '\n') {
         world->pbuffer[world->pbuf_size++] = world->dbuffer[pos];
         world->telnet_state = TELNETFSM_DATA;
+      } else if (world->dbuffer[pos] == '\r') {
+        ++world->telnet_state_ncrs;
       } else {
-        world->pbuffer[world->pbuf_size++] = '\n';
-        if (world->dbuffer[pos] != '\r') {
-          world->pbuffer[world->pbuf_size++] = world->dbuffer[pos];
-          world->telnet_state = TELNETFSM_DATA;
+        int i;
+
+        /* Add the newlines. But check if there is space before. */
+        if (world->pbuf_size + world->telnet_state_ncrs >=
+            world->pbuf_alloc_size) {
+          world->pbuf_alloc_size += world->telnet_state_ncrs;
+          world->pbuffer = g_realloc(world->pbuffer,
+                                     world->pbuf_alloc_size);
         }
+
+        for (i = 0; i < world->telnet_state_ncrs; ++i) {
+          world->pbuffer[world->pbuf_size++] = '\n';
+        }
+        world->pbuffer[world->pbuf_size++] = world->dbuffer[pos];
+        world->telnet_state = TELNETFSM_DATA;
       }
       break;
 
