@@ -1,4 +1,4 @@
-/* $Id: worldgui.c,v 1.47 2006/06/04 17:34:22 ekalin Exp $ */
+/* $Id: worldgui.c,v 1.49 2007/04/22 20:33:10 ekalin Exp $ */
 
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -98,7 +98,6 @@ static gboolean  worldgui_paint_tooltip_cb(GtkWidget      *widget,
                                           GdkEventExpose *event,
                                           gpointer        data);
 static gchar    *worldgui_get_tooltip_text(WorldGUI *gui);
-static void      worldgui_destroy_tooltip_window(WorldGUI *gui);
 static void      textview_size_allocate_cb(GtkWidget     *widget,
                                            GtkAllocation *allocation,
                                            gpointer       data);
@@ -670,6 +669,14 @@ keypress_cb(GtkWidget   *widget,
       return FALSE;
     }
 
+  /* Let Shift+Return and CTRL+Return also work as return */
+  case GDK_Return:
+    if (evt->state & GDK_SHIFT_MASK || evt->state & GDK_CONTROL_MASK) {
+      activate_cb(world->gui->cmbEntry, gui);
+      return TRUE;
+    }
+    return FALSE;
+
   default:
     return check_macros(world, evt->keyval, evt->state);
   }
@@ -1321,7 +1328,6 @@ worldgui_get_tooltip_text(WorldGUI *gui)
 }
 
 
-static
 void
 worldgui_destroy_tooltip_window(WorldGUI *gui)
 {
