@@ -1,4 +1,4 @@
-/* $Id: worlds.c,v 1.90 2006/08/10 14:36:33 ekalin Exp $ */
+/* $Id: worlds.c,v 1.91 2007/05/13 22:00:56 ekalin Exp $ */
 
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -216,6 +216,10 @@ create_new_world(gboolean load_defaults)
     create_default_world();
   }
 
+  /* Create pbuffer */
+  world->pbuffer = (guchar *) g_malloc(MAX_BUFFER);
+  world->pbuf_alloc_size = MAX_BUFFER;
+
   /* Copy defaults */
   world->charset       = g_strdup(default_world->charset);
   world->charset_index = default_world->charset_index;
@@ -360,6 +364,8 @@ free_world(World *world)
   g_free(world->host);
   g_free(world->host_ip);
 
+  g_free(world->pbuffer);
+
   g_object_unref(world->logon_characters);
 
   g_free(world->terminalfont);
