@@ -1,4 +1,4 @@
-/* $Id: worldselector.c,v 1.50 2006/06/23 15:34:15 ekalin Exp $ */
+/* $Id: worldselector.c,v 1.52 2007/01/28 11:46:17 ekalin Exp $ */
 
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -150,8 +150,9 @@ get_world_to_connect()
             gtk_widget_destroy(msgdlg);
             free_world(wrld);
             wrld = NULL;
+          } else {
+            wrld->character_used = charidx;
           }
-          wrld->character_used = charidx;
         }
       }
     } else {    /* Response was not OK */
@@ -228,7 +229,14 @@ create_world_selector_dlg(GtkWindow* parent)
                    G_CALLBACK(list_row_activated_cb), NULL);
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(lstWorlds));
   if (last_open_iter) {
+    GtkTreePath *path;
+
     gtk_tree_selection_select_iter(selection, last_open_iter);
+    path = gtk_tree_model_get_path(GTK_TREE_MODEL(model), last_open_iter);
+    gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(lstWorlds),
+                                 path, NULL,
+                                 FALSE, 0, 0);
+    gtk_tree_path_free(path);
   }
   g_signal_connect(G_OBJECT(selection), "changed",
                    G_CALLBACK(list_selection_changed_cb), NULL);
